{ config, ... }:
{
  virtualisation.oci-containers = {
    containers = {

      jellyfin = {
        image = "linuxserver/jellyfin";
        ports = [ "127.0.0.1:8096:8096" "127.0.0.1:8920:8920" ];
        volumes = [
          "/home/sezycei/srv/containerdata/jellyfin/config:/config"
          "/home/torrent/data/completed:/data/unsorted"
          "/home/torrent/data/TV:/data/tvshows"
          "/home/torrent/data/Movies:/data/movies"
          "/home/torrent/data/transcode:/data/transcode"
          "/home/torrent/data/Music:/data/music"
        ];
        environment = {
          PGID = "1000";
          PUID = "1000";
          TZ = "America/Chicago";
          UMASK_SET = "022";
        };
      };

      legit = {
        image = "docker.matri.cx/legit";
        ports = [ "127.0.0.1:5121:8080" ];
        volumes = [
          "/home/sezycei/srv/containerdata/legit/static:/static"
          "/home/sezycei/srv/containerdata/legit/templates:/templates"
          "/home/sezycei/srv/containerdata/legit/legit.yml:/legit.yml"
          "/home/sezycei/srv/containerdata/legit/repos:/var/www/git"
        ];
        environment = { };
      };

      murmur = {
        image = "goofball222/murmur";
        ports = [ "127.0.0.1:64738:64738" "127.0.0.1:64738:64738/udp" ];
        volumes = [
          "/home/sezycei/srv/containerdata/registry/registry/data:/var/lib/registry"
          "/home/sezycei/srv/containerdata/registry/registry/certs:/certs"
          "/home/sezycei/srv/containerdata/registry/registry/auth:/auth"
        ];
        environment = { };
      };

      purr = {
        image = "docker.matri.cx/purr";
        ports = [ "127.0.0.1:5195:3000" ];
        volumes = [
          "/home/sezycei/dev/purr/data/Purr.sqlite:/app/data/Purr.sqlite"
          "/home/sezycei/dev/purr/config.dhall:/app/config.dhall"
        ];
        environment = { };
      };

      registry = {
        image = "registry:2";
        ports = [ "127.0.0.1:3001:5000" ];
        volumes = [
          "/home/sezycei/srv/containerdata/registry/registry/data:/var/lib/registry"
          "/home/sezycei/srv/containerdata/registry/registry/certs:/certs"
          "/home/sezycei/srv/containerdata/registry/registry/auth:/auth"
        ];
        environment = { };
      };

      transmission = {
        image = "haugene/transmission-openvpn";
        ports = [ "127.0.0.1:9091:9091" ];
        volumes = [
          "/home/sezycei/srv/scripts/transmission/settings.json:/etc/transmission-daemon/settings.json"
          "/etc/localtime:/etc/localtime:ro"
          "/home/torrent/data:/data"
        ];
        environmentFiles =
          [ config.age.secrets.transmission-env.path ];
        extraOptions = [ "--cap-add=NET_ADMIN" "--privileged" ];
      };

    };
  };
}
